@@ -5,6 +5,7 @@
 import configparser
 import logging
 import sys
+import time
 import threading
 
 from remoshock.core.action import Action
@@ -60,7 +61,7 @@ class Remoshock:
                 return None
         channel = self.config.getint(section, "channel")
 
-        if receiver_type.lower() == "dogtra200ncp":
+        if receiver_type.lower() == "dogtra200ncp":  # and self.args.experimental:
             receiver = Dogtra(receiver_properties, code, channel)
         elif receiver_type.lower() == "patpett150":
             receiver = PatpetT150(receiver_properties, code, channel)
@@ -129,7 +130,8 @@ class Remoshock:
 
     def _setup_from_config(self):
         try:
-            self.config = ConfigManager().config
+            self.config_manager = ConfigManager()
+            self.config = self.config_manager.config
             receivers = []
             for receiver in self.config.sections():
                 if receiver.startswith("receiver"):
@@ -248,11 +250,15 @@ class Remoshock:
 
         config = {}
         for section in self.config.sections():
-            if not section.startswith("receiver") and not section == "global":
+            if not section.startswith("#") and not section.startswith("receiver") and not section == "global":
                 config[section] = dict(self.config[section])
-
         result['applications'] = config
 
+        settings = {}
+        for section in self.config_manager.settings.sections():
+            settings[section] = dict(self.config_manager.settings[section])
+        result['settings'] = settings
+
         receivers = []
         for receiver in self.receivers:
             receivers.append(receiver.receiver_properties.__dict__)
@@ -266,8 +272,12 @@ class RemoshockMock(Remoshock):
     """A mock used for testing without requiring any SDR hardware."""
 
 
-    def _process_command(self, receiver, action, power, duration):
-        """do nothing as this is a mock only"""
+    def _process_command(self, _receiver, action, _power, duration):
+        """wait but do nothing, because this is a mock only"""
+
+        if action == Action.BEEPSHOCK:
+            time.sleep(1.2)
+        time.sleep(duration / 1000)
 
 
     def boot(self):
